/*
* Copyright (C) 2022 Associated Universities, Inc. Washington DC, USA.
*
* This file is part of NRAO Workspaces.
*
* Workspaces is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* Workspaces is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
*/
import {Component, Input, OnInit} from '@angular/core';
import {CapabilityRequest} from "../../../../model/capability-request";
import {Capability} from "../../../../model/capability";
import {CapabilityVersion} from "../../../../model/capability-version";
import {HttpClient} from "@angular/common/http";
import {Observable} from "rxjs";
import {WorkflowService} from "../../../../services/workflow.service";

@Component({
  selector: 'da-notes',
  templateUrl: './da-notes.component.html',
  styleUrls: ['./da-notes.component.scss']
})
export class DANotesComponent implements OnInit {
  @Input() capabilityRequest: CapabilityRequest;
  @Input() capability: Capability;
  @Input() currentVersion: CapabilityVersion;

  public daNotes: string;

  constructor( private workflowService: WorkflowService,
    private httpClient: HttpClient,
  ) {}

  ngOnInit(): void {

    if (!this.daNotes) {
      this.getDaNotesURL();
    }
  }

  // Get da_notes contents for editing
  async getDaNotesURL() {
    this.daNotes = await new Promise<string>(resolve =>
      this.retrieveFromDaNotesEndpoint().subscribe(notes => resolve(notes['resp'])));
  }

  private retrieveFromDaNotesEndpoint(): Observable<string> {
    var curCapabilityRequestId = this.capabilityRequest.id;
    var curCapabilityVersion = this.currentVersion.version_number.toString();
    const url = "/capability/request/" + curCapabilityRequestId + "/version/" + curCapabilityVersion + "/da_notes";

    return this.httpClient.get<any>(url);
  }

  private saveDaNotesObserver = {
    next: () => {},
    error: (error) => console.error("Error when saving DA notes edit:", error),
  };

  private saveDaNotes(edits: string): Observable<string> {
    var curCapabilityRequestId = this.capabilityRequest.id;
    var curCapabilityVersion = this.currentVersion.version_number.toString();
    const url = "/capability/request/" + curCapabilityRequestId + "/version/" + curCapabilityVersion + "/da_notes";

    return this.httpClient.post<any>(url, JSON.stringify({"edits":edits}));
  }

  emitEditEventToParent(edits: string): void {
    this.saveDaNotes(edits).subscribe(this.saveDaNotesObserver);
    this.getDaNotesURL();
  }
}
