# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""added errexit to std_calibration script template

Revision ID: 2ac701610fc7
Revises: 12b2de18a383
Create Date: 2021-07-01 16:04:31.042789

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "2ac701610fc7"
down_revision = "12b2de18a383"
branch_labels = None
depends_on = None


def upgrade():
    shell_script_content_std_calibration = """#!/bin/sh

export HOME=$TMPDIR

set -o errexit
./framework.sh -d .
chmod 770 .
cd rawdata/
../productfetcher --product-locator $1
cd ../
./casa_envoy --standard-cal $3 $4
./conveyor --deliver $3

"""

    op.execute(
        "UPDATE workflow_templates "
        f"SET content = E'{shell_script_content_std_calibration}' "
        "WHERE filename = 'std_calibration.sh'"
    )


def downgrade():
    shell_script_content_std_calibration = """#!/bin/sh

export HOME=$TMPDIR

./framework.sh -d .
chmod 770 .
cd rawdata/
../productfetcher --product-locator $1
cd ../
./casa_envoy --standard-cal $3 $4
./conveyor --deliver $3

"""

    op.execute(
        "UPDATE workflow_templates "
        f"SET content = E'{shell_script_content_std_calibration}' "
        "WHERE filename = 'std_calibration.sh'"
    )
